==> ghost-bot.js-1.0.1.tgz: package/src/client/Client.js <==
const EventEmitter = require('events');
const { UserManager, ChannelManager, GuildManager } = require('discord.js');
const { Events } = require('discord.js').Util;
const WebSocketManager = require('../websocket/Manager');

class Client extends EventEmitter {
  constructor(options) {
    this.client = client;
    this.ws = new WebSocketManager(this);
    this.users = new UserManager(this);
    this.guilds = new GuildManager(this);
    this.channels = new ChannelManager(this);
    Object.defineProperty(this, 'token', { writable: true });
    if (!this.token && 'DISCORD_TOKEN' in process.env) {
      this.token = process.env.DISCORD_TOKEN;
    } else {
      this.token = null;
    }
  }

  run(token = this.token) {
    if (!token || typeof token !== 'string') throw new TypeError('Bot tokeni eksik.');
    this.token = token = token.replace(/^(Bot|Bearer)\s*/i, '');
    this.emit(
      Events.DEBUG,
      `Sağlanan jeton: ${token
        .split('.')
        .map((val, i) => (i > 1 ? val.replace(/./g, '*') : val))
        .join('.')}`,
    );

    if (this.options.presence) {
      this.options.ws.presence = this.presence._parse(this.options.presence);
    }

    this.emit(Events.DEBUG, 'Ağ geçidine bağlanmaya hazırlanıyor...');

    try {
      this.ws.connect();
      return this.token;
    } catch (error) {
      this.destroy();
      throw new Error(error);
    }
  }

  destroy() {
    super.destroy();
    this.ws.destroy();
    this.token = null;
  }
}

module.exports = Client;

==> ghost-bot.js-1.2.1.tgz: package/src/client/Client.js <==
const EventEmitter = require('events');
const { UserManager, ChannelManager, GuildManager } = require('discord.js');
const { Events } = require('discord.js').Util;
const WebSocketManager = require('../websocket/Manager');

class Client extends EventEmitter {
  constructor(options) {
    super(Object.assign({ _tokenType: 'Bot' }, options));
      this.ws = new WebSocketManager(this);
      this.users = new UserManager(this);
      this.guilds = new GuildManager(this);
      this.channels = new ChannelManager(this);
      Object.defineProperty(this, 'token', { 
        writable: true 
      });
      if (!this.token && 'DISCORD_TOKEN' in process.env) {
        this.token = process.env.DISCORD_TOKEN;
      } else {
        this.token = null;
      }
  }

  run(token = this.token) {
    if (!token || typeof token !== 'string') throw new TypeError('Bot tokeni eksik.');
    this.token = token = token.replace(/^(Bot|Bearer)\s*/i, '');
    this.emit(
      Events.DEBUG,
      `Sağlanan jeton: ${token
        .split('.')
        .map((val, i) => (i > 1 ? val.replace(/./g, '*') : val))
        .join('.')}`,
    );

    if (this.options.presence) {
      this.options.ws.presence = this.presence._parse(this.options.presence);
    }

    this.emit(Events.DEBUG, 'Ağ geçidine bağlanmaya hazırlanıyor...');

    try {
      this.ws.connect();
      return this.token;
    } catch (error) {
      this.destroy();
      throw new Error(error);
    }
  }

  destroy() {
    super.destroy();
    this.ws.destroy();
    this.token = null;
  }
}

module.exports = Client;
